<br /> 
<div align="center">
  <a href="https://github.com/githashem/djplus">
    <img src="https://raw.githubusercontent.com/githashem/djplus/main/logo.svg" alt="Djplus Logo" width="80" height="80">
  </a>
<h2 align="center">A package of ready-made apps</h2>
</div>

![djplus version](https://img.shields.io/pypi/v/djplus?style=flat-square)
